@@ -54,18 +54,6 @@ OC.L10N.register(
     "{displayName} (team)" : "{displayName} (team)",
     "Add group or team" : "Tilføj gruppe eller team",
     "{size} used" : "{size} brugt",
-    "You can not remove your own read permission." : "Du kan ikke fjerne din egen læserettighed.",
-    "Group folders" : "Gruppemapper",
-    "Admin configured folders shared with everyone in a group" : "Administratorkonfigurerede mapper deles med alle i en gruppe",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i en gruppe.\n\nMapper kan konfigureres fra *Gruppemapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for en eller flere grupper, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.",
-    "Group folder" : "Gruppemappe",
-    "Open group folder" : "Åben gruppemappe",
-    "List of group folders." : "Liste med gruppemapper",
-    "No group folders yet" : "Endnu ingen gruppemapper",
-    "Group folders will show up here" : "Gruppemapper vil blive vist her",
-    "Group folder admin delegation" : "Gruppemapper administrator rettigheder ",
-    "They will have access to all group folders." : "De vil have adgang til gruppemapper.",
-    "They will only have access to group folders for which they have advanced permissions." : "De vil kun have adgang til gruppemapper til hvilke de har avancerede rettigheder.",
     "Admin configured folders shared with everyone in a team" : "Admin konfigurerede mapper som er delt med alle i teamet",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin konfigurede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i adminindstillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgang til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Admin konfigurerede mapper der er delt med alle i et team.\n\nMapper kan konfigureres fra *Teammapper* i admin indtillingerne.\n\nEfter at en mappe er oprettet, så kan admin give adgan til mappen for et eller flere teams, kontrollere deres skrive-/delingsrettigheder og tildele en kvote til mappen.\nFra og med Hub 10/Nextcloud 31, skal admin være en del af teamet for at kunne tildele en teammappe til det."
