@@ -5,10 +5,14 @@ OC.L10N.register(
     "Deny" : "Agwi",
     "Allow" : "Sireg",
     "Group" : "Agraw",
+    "Team" : "Tarbaɛt",
+    "Read" : "Taɣuri",
     "Create" : "Snulfu-d",
     "Delete" : "Kkes",
     "Share" : "Bḍu",
+    "You" : "Kemm·čč",
     "Default" : "Prédéfini(e)",
+    "Folder name" : "Isem n ukaram",
     "Previous" : "Ɣer deffir",
     "Next" : "Uḍfir",
     "User" : "Aseqdac",
