@@ -15,8 +15,8 @@ use Symfony\Component\Console\Output\OutputInterface;
 
 class ExpireGroupTrash extends ExpireGroupBase {
 	public function __construct(
-		private TrashBackend $trashBackend,
-		private Expiration $expiration,
+		private readonly TrashBackend $trashBackend,
+		private readonly Expiration $expiration,
 	) {
 		parent::__construct();
 	}
