@@ -1,5 +1,6 @@
 <?php
 
+declare (strict_types=1);
 /**
  * SPDX-FileCopyrightText: 2022 Baptiste Fotia <baptiste.fotia@arawa.fr> for Arawa (https://arawa.fr)
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -12,7 +13,7 @@ use OCP\App\IAppManager;
 
 class ApplicationService {
 	public function __construct(
-		private IAppManager $appManager,
+		private readonly IAppManager $appManager,
 	) {
 	}
 
@@ -21,7 +22,7 @@ class ApplicationService {
 	 * @return boolean true if all apps are installed, false otherwise.
 	 */
 	public function checkAppsInstalled(): bool {
-		$diffApps = array_diff(Application::APPS_USE_GROUPFOLDERS, $this->appManager->getInstalledApps());
+		$diffApps = array_diff(Application::APPS_USE_GROUPFOLDERS, $this->appManager->getEnabledApps());
 
 		return empty($diffApps);
 	}
